@@ -17,7 +17,7 @@ use MIME::Base64;
 
 our @ISA=('Baseobject' );
 our @EXPORT = qw (verbosity);
-my $version ='$Id: Ldapsearch.pm 46985 2017-09-15 13:34:04Z anton $ ';
+my $version ='$Id: Ldapsearch.pm 50026 2022-10-11 14:10:44Z anton $ ';
 
 my $SELF;
 my $hierarchy = {};
@@ -133,7 +133,7 @@ sub ldapinit {
 			password=>$self->{fields}->{bindpwd}
 			);
 		if ($msg->code) {
-			warn "error binding $self->{fields}->{binddn} on ldapserver: $type://$host", $msg->error();
+			warn "error binding $self->{fields}->{binddn} on ldapserver: $type://$host pw: \"$self->{fields}->{bindpwd}\" ", $msg->error();
 			$self->error($msg->error());
 		} else {
 			warn "BIND SUCCESSFUL FOR $self->{fields}->{binddn}, ldapserver: $host" if $self->{fields}->{cfhash}->{dumpldap};
